mount

package
v1.34.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 20, 2025 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Overview

Package mount is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DeviceStats

type DeviceStats struct {
	Block bool

	AvailableBytes  int64
	TotalBytes      int64
	UsedBytes       int64
	AvailableInodes int64
	TotalInodes     int64
	UsedInodes      int64
}

type IMount

type IMount interface {
	Mounter() *mount.SafeFormatAndMount
	ScanForAttach(devicePath string) error
	GetDevicePath(volumeID string) (string, error)
	IsLikelyNotMountPointAttach(targetpath string) (bool, error)
	UnmountPath(mountPath string) error
	MakeFile(pathname string) error
	MakeDir(pathname string) error
	GetDeviceStats(path string) (*DeviceStats, error)
	GetMountFs(path string) ([]byte, error)
}
var MInstance IMount

func GetMountProvider

func GetMountProvider() IMount

GetMountProvider returns instance of Mounter

type MockIMount

type MockIMount struct {
	// contains filtered or unexported fields
}

MockIMount is a mock of IMount interface.

func NewMockIMount

func NewMockIMount(ctrl *gomock.Controller) *MockIMount

NewMockIMount creates a new mock instance.

func (*MockIMount) EXPECT

func (m *MockIMount) EXPECT() *MockIMountMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockIMount) GetDevicePath

func (m *MockIMount) GetDevicePath(volumeID string) (string, error)

GetDevicePath mocks base method.

func (*MockIMount) GetDeviceStats

func (m *MockIMount) GetDeviceStats(path string) (*DeviceStats, error)

GetDeviceStats mocks base method.

func (*MockIMount) GetMountFs

func (m *MockIMount) GetMountFs(path string) ([]byte, error)

GetMountFs mocks base method.

func (*MockIMount) IsLikelyNotMountPointAttach

func (m *MockIMount) IsLikelyNotMountPointAttach(targetpath string) (bool, error)

IsLikelyNotMountPointAttach mocks base method.

func (*MockIMount) MakeDir

func (m *MockIMount) MakeDir(pathname string) error

MakeDir mocks base method.

func (*MockIMount) MakeFile

func (m *MockIMount) MakeFile(pathname string) error

MakeFile mocks base method.

func (*MockIMount) Mounter

func (m *MockIMount) Mounter() *mount0.SafeFormatAndMount

Mounter mocks base method.

func (*MockIMount) ScanForAttach

func (m *MockIMount) ScanForAttach(devicePath string) error

ScanForAttach mocks base method.

func (*MockIMount) UnmountPath

func (m *MockIMount) UnmountPath(mountPath string) error

UnmountPath mocks base method.

type MockIMountMockRecorder

type MockIMountMockRecorder struct {
	// contains filtered or unexported fields
}

MockIMountMockRecorder is the mock recorder for MockIMount.

func (*MockIMountMockRecorder) GetDevicePath

func (mr *MockIMountMockRecorder) GetDevicePath(volumeID any) *gomock.Call

GetDevicePath indicates an expected call of GetDevicePath.

func (*MockIMountMockRecorder) GetDeviceStats

func (mr *MockIMountMockRecorder) GetDeviceStats(path any) *gomock.Call

GetDeviceStats indicates an expected call of GetDeviceStats.

func (*MockIMountMockRecorder) GetMountFs

func (mr *MockIMountMockRecorder) GetMountFs(path any) *gomock.Call

GetMountFs indicates an expected call of GetMountFs.

func (*MockIMountMockRecorder) IsLikelyNotMountPointAttach

func (mr *MockIMountMockRecorder) IsLikelyNotMountPointAttach(targetpath any) *gomock.Call

IsLikelyNotMountPointAttach indicates an expected call of IsLikelyNotMountPointAttach.

func (*MockIMountMockRecorder) MakeDir

func (mr *MockIMountMockRecorder) MakeDir(pathname any) *gomock.Call

MakeDir indicates an expected call of MakeDir.

func (*MockIMountMockRecorder) MakeFile

func (mr *MockIMountMockRecorder) MakeFile(pathname any) *gomock.Call

MakeFile indicates an expected call of MakeFile.

func (*MockIMountMockRecorder) Mounter

func (mr *MockIMountMockRecorder) Mounter() *gomock.Call

Mounter indicates an expected call of Mounter.

func (*MockIMountMockRecorder) ScanForAttach

func (mr *MockIMountMockRecorder) ScanForAttach(devicePath any) *gomock.Call

ScanForAttach indicates an expected call of ScanForAttach.

func (*MockIMountMockRecorder) UnmountPath

func (mr *MockIMountMockRecorder) UnmountPath(mountPath any) *gomock.Call

UnmountPath indicates an expected call of UnmountPath.

type Mount

type Mount struct {
	BaseMounter *mount.SafeFormatAndMount
}

func (*Mount) GetDevicePath

func (m *Mount) GetDevicePath(volumeID string) (string, error)

GetDevicePath returns the path of an attached block storage volume, specified by its id.

func (*Mount) GetDeviceStats

func (m *Mount) GetDeviceStats(devicePath string) (*DeviceStats, error)

func (*Mount) GetMountFs

func (m *Mount) GetMountFs(volumePath string) ([]byte, error)

func (*Mount) IsLikelyNotMountPointAttach

func (m *Mount) IsLikelyNotMountPointAttach(targetpath string) (bool, error)

IsLikelyNotMountPointAttach

func (*Mount) MakeDir

func (m *Mount) MakeDir(pathname string) error

MakeDir creates dir

func (*Mount) MakeFile

func (m *Mount) MakeFile(pathname string) error

MakeFile creates an empty file

func (*Mount) Mounter

func (m *Mount) Mounter() *mount.SafeFormatAndMount

Mounter returns instance of SafeFormatAndMount

func (*Mount) ScanForAttach

func (m *Mount) ScanForAttach(devicePath string) error

ScanForAttach

func (*Mount) UnmountPath

func (m *Mount) UnmountPath(mountPath string) error

UnmountPath

Jump to